powered by
This helper prepares character vectors for use in shell commands by quoting them with shQuote() and (double) escaping any internal double quotes.
shQuote()
escapedQuote(x, double = FALSE)
A character vector with all double quotes double escaped so that it can safely be passed to a command line call.
A character vector that may contain double quotes.
Boolean. Should the quotes be escaped twice? Default: FALSE
if (FALSE) { escapedQuote('foo "bar" baz') }
Run the code above in your browser using DataLab